"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from .createdataset import (
    CreateDatasetRequestBody,
    CreateDatasetRequestBodyTypedDict,
    CreateDatasetResponse,
    CreateDatasetResponseBody,
    CreateDatasetResponseBodyTypedDict,
    CreateDatasetResponseTypedDict,
    Datasets,
    DatasetsTypedDict,
)
from .createelement import (
    CreateElementRequestBody,
    CreateElementRequestBodyTypedDict,
    CreateElementResponse,
    CreateElementResponseBody,
    CreateElementResponseBodyTypedDict,
    CreateElementResponseTypedDict,
    SDTrainingOutput,
    SDTrainingOutputTypedDict,
    SdVersions,
)
from .creategeneration import (
    CreateGenerationRequestBody,
    CreateGenerationRequestBodyTypedDict,
    CreateGenerationResponse,
    CreateGenerationResponseBody,
    CreateGenerationResponseBodyTypedDict,
    CreateGenerationResponseTypedDict,
    SDGenerationOutput,
    SDGenerationOutputTypedDict,
    TransparencyType,
)
from .createlcmgeneration import (
    CreateLCMGenerationRequestBody,
    CreateLCMGenerationRequestBodyTypedDict,
    CreateLCMGenerationResponse,
    CreateLCMGenerationResponseBody,
    CreateLCMGenerationResponseBodyTypedDict,
    CreateLCMGenerationResponseTypedDict,
    LcmGenerationOutput,
    LcmGenerationOutputTypedDict,
)
from .createmodel import (
    CreateModelRequestBody,
    CreateModelRequestBodyTypedDict,
    CreateModelResponse,
    CreateModelResponseBody,
    CreateModelResponseBodyTypedDict,
    CreateModelResponseTypedDict,
    CreateModelSDTrainingOutput,
    CreateModelSDTrainingOutputTypedDict,
    CreateModelSdVersions,
)
from .createsvdmotiongeneration import (
    CreateSVDMotionGenerationRequestBody,
    CreateSVDMotionGenerationRequestBodyTypedDict,
    CreateSVDMotionGenerationResponse,
    CreateSVDMotionGenerationResponseBody,
    CreateSVDMotionGenerationResponseBodyTypedDict,
    CreateSVDMotionGenerationResponseTypedDict,
    MotionSvdGenerationOutput,
    MotionSvdGenerationOutputTypedDict,
)
from .createtexturegeneration import (
    CreateTextureGenerationRequestBody,
    CreateTextureGenerationRequestBodyTypedDict,
    CreateTextureGenerationResponse,
    CreateTextureGenerationResponseBody,
    CreateTextureGenerationResponseBodyTypedDict,
    CreateTextureGenerationResponseTypedDict,
    TextureGenerationJobOutput,
    TextureGenerationJobOutputTypedDict,
)
from .createuniversalupscalerjob import (
    CreateUniversalUpscalerJobRequestBody,
    CreateUniversalUpscalerJobRequestBodyTypedDict,
    CreateUniversalUpscalerJobResponse,
    CreateUniversalUpscalerJobResponseBody,
    CreateUniversalUpscalerJobResponseBodyTypedDict,
    CreateUniversalUpscalerJobResponseTypedDict,
    UniversalUpscalerOutput,
    UniversalUpscalerOutputTypedDict,
)
from .createvariationnobg import (
    CreateVariationNoBGRequestBody,
    CreateVariationNoBGRequestBodyTypedDict,
    CreateVariationNoBGResponse,
    CreateVariationNoBGResponseBody,
    CreateVariationNoBGResponseBodyTypedDict,
    CreateVariationNoBGResponseTypedDict,
    SDUpscaleJobOutput,
    SDUpscaleJobOutputTypedDict,
)
from .createvariationunzoom import (
    CreateVariationUnzoomRequestBody,
    CreateVariationUnzoomRequestBodyTypedDict,
    CreateVariationUnzoomResponse,
    CreateVariationUnzoomResponseBody,
    CreateVariationUnzoomResponseBodyTypedDict,
    CreateVariationUnzoomResponseTypedDict,
    SDUnzoomOutput,
    SDUnzoomOutputTypedDict,
)
from .createvariationupscale import (
    CreateVariationUpscaleRequestBody,
    CreateVariationUpscaleRequestBodyTypedDict,
    CreateVariationUpscaleResponse,
    CreateVariationUpscaleResponseBody,
    CreateVariationUpscaleResponseBodyTypedDict,
    CreateVariationUpscaleResponseTypedDict,
    CreateVariationUpscaleSDUpscaleJobOutput,
    CreateVariationUpscaleSDUpscaleJobOutputTypedDict,
)
from .delete3dmodelbyid import (
    Delete3DModelByIDRequest,
    Delete3DModelByIDRequestBody,
    Delete3DModelByIDRequestBodyTypedDict,
    Delete3DModelByIDRequestTypedDict,
    Delete3DModelByIDResponse,
    Delete3DModelByIDResponseBody,
    Delete3DModelByIDResponseBodyTypedDict,
    Delete3DModelByIDResponseTypedDict,
    ModelAssets,
    ModelAssetsTypedDict,
)
from .deletedatasetbyid import (
    DeleteDatasetByIDDatasets,
    DeleteDatasetByIDDatasetsTypedDict,
    DeleteDatasetByIDRequest,
    DeleteDatasetByIDRequestTypedDict,
    DeleteDatasetByIDResponse,
    DeleteDatasetByIDResponseBody,
    DeleteDatasetByIDResponseBodyTypedDict,
    DeleteDatasetByIDResponseTypedDict,
)
from .deleteelementbyid import (
    DeleteElementByIDRequest,
    DeleteElementByIDRequestTypedDict,
    DeleteElementByIDResponse,
    DeleteElementByIDResponseBody,
    DeleteElementByIDResponseBodyTypedDict,
    DeleteElementByIDResponseTypedDict,
    UserLoras,
    UserLorasTypedDict,
)
from .deletegenerationbyid import (
    DeleteGenerationByIDRequest,
    DeleteGenerationByIDRequestTypedDict,
    DeleteGenerationByIDResponse,
    DeleteGenerationByIDResponseBody,
    DeleteGenerationByIDResponseBodyTypedDict,
    DeleteGenerationByIDResponseTypedDict,
    Generations,
    GenerationsTypedDict,
)
from .deleteinitimagebyid import (
    DeleteInitImageByIDRequest,
    DeleteInitImageByIDRequestTypedDict,
    DeleteInitImageByIDResponse,
    DeleteInitImageByIDResponseBody,
    DeleteInitImageByIDResponseBodyTypedDict,
    DeleteInitImageByIDResponseTypedDict,
    InitImages,
    InitImagesTypedDict,
)
from .deletemodelbyid import (
    CustomModels,
    CustomModelsTypedDict,
    DeleteModelByIDRequest,
    DeleteModelByIDRequestTypedDict,
    DeleteModelByIDResponse,
    DeleteModelByIDResponseBody,
    DeleteModelByIDResponseBodyTypedDict,
    DeleteModelByIDResponseTypedDict,
)
from .deletetexturegenerationbyid import (
    DeleteTextureGenerationByIDRequest,
    DeleteTextureGenerationByIDRequestBody,
    DeleteTextureGenerationByIDRequestBodyTypedDict,
    DeleteTextureGenerationByIDRequestTypedDict,
    DeleteTextureGenerationByIDResponse,
    DeleteTextureGenerationByIDResponseBody,
    DeleteTextureGenerationByIDResponseBodyTypedDict,
    DeleteTextureGenerationByIDResponseTypedDict,
    ModelAssetTextureGenerations,
    ModelAssetTextureGenerationsTypedDict,
)
from .get3dmodelbyid import (
    Get3DModelByIDModelAssets,
    Get3DModelByIDModelAssetsTypedDict,
    Get3DModelByIDRequest,
    Get3DModelByIDRequestBody,
    Get3DModelByIDRequestBodyTypedDict,
    Get3DModelByIDRequestTypedDict,
    Get3DModelByIDResponse,
    Get3DModelByIDResponseBody,
    Get3DModelByIDResponseBodyTypedDict,
    Get3DModelByIDResponseTypedDict,
)
from .get3dmodelsbyuserid import (
    Get3DModelsByUserIDModelAssets,
    Get3DModelsByUserIDModelAssetsTypedDict,
    Get3DModelsByUserIDRequest,
    Get3DModelsByUserIDRequestBody,
    Get3DModelsByUserIDRequestBodyTypedDict,
    Get3DModelsByUserIDRequestTypedDict,
    Get3DModelsByUserIDResponse,
    Get3DModelsByUserIDResponseBody,
    Get3DModelsByUserIDResponseBodyTypedDict,
    Get3DModelsByUserIDResponseTypedDict,
)
from .getcustomelementsbyuserid import (
    GetCustomElementsByUserIDRequest,
    GetCustomElementsByUserIDRequestTypedDict,
    GetCustomElementsByUserIDResponse,
    GetCustomElementsByUserIDResponseBody,
    GetCustomElementsByUserIDResponseBodyTypedDict,
    GetCustomElementsByUserIDResponseTypedDict,
    GetCustomElementsByUserIDUserLoras,
    GetCustomElementsByUserIDUserLorasTypedDict,
)
from .getcustommodelsbyuserid import (
    GetCustomModelsByUserIDCustomModels,
    GetCustomModelsByUserIDCustomModelsTypedDict,
    GetCustomModelsByUserIDRequest,
    GetCustomModelsByUserIDRequestTypedDict,
    GetCustomModelsByUserIDResponse,
    GetCustomModelsByUserIDResponseBody,
    GetCustomModelsByUserIDResponseBodyTypedDict,
    GetCustomModelsByUserIDResponseTypedDict,
)
from .getdatasetbyid import (
    DatasetImages,
    DatasetImagesTypedDict,
    GetDatasetByIDDatasets,
    GetDatasetByIDDatasetsTypedDict,
    GetDatasetByIDRequest,
    GetDatasetByIDRequestTypedDict,
    GetDatasetByIDResponse,
    GetDatasetByIDResponseBody,
    GetDatasetByIDResponseBodyTypedDict,
    GetDatasetByIDResponseTypedDict,
)
from .getelementbyid import (
    GetElementByIDRequest,
    GetElementByIDRequestTypedDict,
    GetElementByIDResponse,
    GetElementByIDResponseBody,
    GetElementByIDResponseBodyTypedDict,
    GetElementByIDResponseTypedDict,
    GetElementByIDUserLoras,
    GetElementByIDUserLorasTypedDict,
)
from .getgenerationbyid import (
    GeneratedImages,
    GeneratedImagesTypedDict,
    GenerationElements,
    GenerationElementsTypedDict,
    GetGenerationByIDGeneratedImageVariationGeneric,
    GetGenerationByIDGeneratedImageVariationGenericTypedDict,
    GetGenerationByIDGenerations,
    GetGenerationByIDGenerationsTypedDict,
    GetGenerationByIDLoras,
    GetGenerationByIDLorasTypedDict,
    GetGenerationByIDRequest,
    GetGenerationByIDRequestTypedDict,
    GetGenerationByIDResponse,
    GetGenerationByIDResponseBody,
    GetGenerationByIDResponseBodyTypedDict,
    GetGenerationByIDResponseTypedDict,
)
from .getgenerationsbyuserid import (
    Elements,
    ElementsTypedDict,
    GetGenerationsByUserIDGeneratedImageVariationGeneric,
    GetGenerationsByUserIDGeneratedImageVariationGenericTypedDict,
    GetGenerationsByUserIDGeneratedImages,
    GetGenerationsByUserIDGeneratedImagesTypedDict,
    GetGenerationsByUserIDGenerationElements,
    GetGenerationsByUserIDGenerationElementsTypedDict,
    GetGenerationsByUserIDGenerations,
    GetGenerationsByUserIDGenerationsTypedDict,
    GetGenerationsByUserIDRequest,
    GetGenerationsByUserIDRequestTypedDict,
    GetGenerationsByUserIDResponse,
    GetGenerationsByUserIDResponseBody,
    GetGenerationsByUserIDResponseBodyTypedDict,
    GetGenerationsByUserIDResponseTypedDict,
)
from .getinitimagebyid import (
    GetInitImageByIDInitImages,
    GetInitImageByIDInitImagesTypedDict,
    GetInitImageByIDRequest,
    GetInitImageByIDRequestTypedDict,
    GetInitImageByIDResponse,
    GetInitImageByIDResponseBody,
    GetInitImageByIDResponseBodyTypedDict,
    GetInitImageByIDResponseTypedDict,
)
from .getmodelbyid import (
    GetModelByIDCustomModels,
    GetModelByIDCustomModelsTypedDict,
    GetModelByIDRequest,
    GetModelByIDRequestTypedDict,
    GetModelByIDResponse,
    GetModelByIDResponseBody,
    GetModelByIDResponseBodyTypedDict,
    GetModelByIDResponseTypedDict,
)
from .gettexturegenerationbyid import (
    GetTextureGenerationByIDModelAssetTextureGenerations,
    GetTextureGenerationByIDModelAssetTextureGenerationsTypedDict,
    GetTextureGenerationByIDRequest,
    GetTextureGenerationByIDRequestBody,
    GetTextureGenerationByIDRequestBodyTypedDict,
    GetTextureGenerationByIDRequestTypedDict,
    GetTextureGenerationByIDResponse,
    GetTextureGenerationByIDResponseBody,
    GetTextureGenerationByIDResponseBodyTypedDict,
    GetTextureGenerationByIDResponseTypedDict,
    ModelAssetTextureImages,
    ModelAssetTextureImagesTypedDict,
)
from .gettexturegenerationsbymodelid import (
    GetTextureGenerationsByModelIDModelAssetTextureGenerations,
    GetTextureGenerationsByModelIDModelAssetTextureGenerationsTypedDict,
    GetTextureGenerationsByModelIDModelAssetTextureImages,
    GetTextureGenerationsByModelIDModelAssetTextureImagesTypedDict,
    GetTextureGenerationsByModelIDRequest,
    GetTextureGenerationsByModelIDRequestBody,
    GetTextureGenerationsByModelIDRequestBodyTypedDict,
    GetTextureGenerationsByModelIDRequestTypedDict,
    GetTextureGenerationsByModelIDResponse,
    GetTextureGenerationsByModelIDResponseBody,
    GetTextureGenerationsByModelIDResponseBodyTypedDict,
    GetTextureGenerationsByModelIDResponseTypedDict,
)
from .getuserself import (
    GetUserSelfResponse,
    GetUserSelfResponseBody,
    GetUserSelfResponseBodyTypedDict,
    GetUserSelfResponseTypedDict,
    UserDetails,
    UserDetailsTypedDict,
    Users,
    UsersTypedDict,
)
from .getvariationbyid import (
    GeneratedImageVariationGeneric,
    GeneratedImageVariationGenericTypedDict,
    GetVariationByIDRequest,
    GetVariationByIDRequestTypedDict,
    GetVariationByIDResponse,
    GetVariationByIDResponseBody,
    GetVariationByIDResponseBodyTypedDict,
    GetVariationByIDResponseTypedDict,
)
from .listelements import (
    ListElementsResponse,
    ListElementsResponseBody,
    ListElementsResponseBodyTypedDict,
    ListElementsResponseTypedDict,
    Loras,
    LorasTypedDict,
)
from .listplatformmodels import (
    ListPlatformModelsCustomModels,
    ListPlatformModelsCustomModelsTypedDict,
    ListPlatformModelsGeneratedImages,
    ListPlatformModelsGeneratedImagesTypedDict,
    ListPlatformModelsResponse,
    ListPlatformModelsResponseBody,
    ListPlatformModelsResponseBodyTypedDict,
    ListPlatformModelsResponseTypedDict,
)
from .performalchemyupscalelcm import (
    PerformAlchemyUpscaleLCMLCMGenerationOutput,
    PerformAlchemyUpscaleLCMLCMGenerationOutputTypedDict,
    PerformAlchemyUpscaleLCMRequestBody,
    PerformAlchemyUpscaleLCMRequestBodyTypedDict,
    PerformAlchemyUpscaleLCMResponse,
    PerformAlchemyUpscaleLCMResponseBody,
    PerformAlchemyUpscaleLCMResponseBodyTypedDict,
    PerformAlchemyUpscaleLCMResponseTypedDict,
)
from .performinpaintinglcm import (
    PerformInpaintingLCMLCMGenerationOutput,
    PerformInpaintingLCMLCMGenerationOutputTypedDict,
    PerformInpaintingLCMRequestBody,
    PerformInpaintingLCMRequestBodyTypedDict,
    PerformInpaintingLCMResponse,
    PerformInpaintingLCMResponseBody,
    PerformInpaintingLCMResponseBodyTypedDict,
    PerformInpaintingLCMResponseTypedDict,
)
from .performinstantrefine import (
    PerformInstantRefineLcmGenerationOutput,
    PerformInstantRefineLcmGenerationOutputTypedDict,
    PerformInstantRefineRequestBody,
    PerformInstantRefineRequestBodyTypedDict,
    PerformInstantRefineResponse,
    PerformInstantRefineResponseBody,
    PerformInstantRefineResponseBodyTypedDict,
    PerformInstantRefineResponseTypedDict,
)
from .pricingcalculator import (
    CalculateProductionAPIServiceCost,
    CalculateProductionAPIServiceCostTypedDict,
    Object,
    ObjectTypedDict,
    PricingCalculatorObject,
    PricingCalculatorObjectTypedDict,
    PricingCalculatorPricingCalculatorObject,
    PricingCalculatorPricingCalculatorObjectTypedDict,
    PricingCalculatorPricingCalculatorRequestObject,
    PricingCalculatorPricingCalculatorRequestObjectTypedDict,
    PricingCalculatorPricingCalculatorRequestRequestBodyObject,
    PricingCalculatorPricingCalculatorRequestRequestBodyObjectTypedDict,
    PricingCalculatorPricingCalculatorRequestRequestBodyServiceParamsObject,
    PricingCalculatorPricingCalculatorRequestRequestBodyServiceParamsObjectTypedDict,
    PricingCalculatorPricingCalculatorRequestRequestBodyServiceParamsTEXTUREGENERATIONObject,
    PricingCalculatorPricingCalculatorRequestRequestBodyServiceParamsTEXTUREGENERATIONObjectTypedDict,
    PricingCalculatorPricingCalculatorRequestRequestBodyServiceParamsUNIVERSALUPSCALERObject,
    PricingCalculatorPricingCalculatorRequestRequestBodyServiceParamsUNIVERSALUPSCALERObjectTypedDict,
    PricingCalculatorPricingCalculatorRequestRequestBodyServiceParamsUNIVERSALUPSCALERULTRAObject,
    PricingCalculatorPricingCalculatorRequestRequestBodyServiceParamsUNIVERSALUPSCALERULTRAObjectTypedDict,
    PricingCalculatorRequestBody,
    PricingCalculatorRequestBodyTypedDict,
    PricingCalculatorResponse,
    PricingCalculatorResponseBody,
    PricingCalculatorResponseBodyTypedDict,
    PricingCalculatorResponseTypedDict,
)
from .promptimprove import (
    PromptGenerationOutput,
    PromptGenerationOutputTypedDict,
    PromptImproveRequestBody,
    PromptImproveRequestBodyTypedDict,
    PromptImproveResponse,
    PromptImproveResponseBody,
    PromptImproveResponseBodyTypedDict,
    PromptImproveResponseTypedDict,
)
from .promptrandom import (
    PromptRandomPromptGenerationOutput,
    PromptRandomPromptGenerationOutputTypedDict,
    PromptRandomResponse,
    PromptRandomResponseBody,
    PromptRandomResponseBodyTypedDict,
    PromptRandomResponseTypedDict,
)
from .uploadcanvasinitimage import (
    CanvasInitImageUploadOutput,
    CanvasInitImageUploadOutputTypedDict,
    UploadCanvasInitImageRequestBody,
    UploadCanvasInitImageRequestBodyTypedDict,
    UploadCanvasInitImageResponse,
    UploadCanvasInitImageResponseBody,
    UploadCanvasInitImageResponseBodyTypedDict,
    UploadCanvasInitImageResponseTypedDict,
)
from .uploaddatasetimage import (
    DatasetUploadOutput,
    DatasetUploadOutputTypedDict,
    UploadDatasetImageRequest,
    UploadDatasetImageRequestBody,
    UploadDatasetImageRequestBodyTypedDict,
    UploadDatasetImageRequestTypedDict,
    UploadDatasetImageResponse,
    UploadDatasetImageResponseBody,
    UploadDatasetImageResponseBodyTypedDict,
    UploadDatasetImageResponseTypedDict,
)
from .uploaddatasetimagefromgen import (
    DatasetGenUploadOutput,
    DatasetGenUploadOutputTypedDict,
    UploadDatasetImageFromGenRequest,
    UploadDatasetImageFromGenRequestBody,
    UploadDatasetImageFromGenRequestBodyTypedDict,
    UploadDatasetImageFromGenRequestTypedDict,
    UploadDatasetImageFromGenResponse,
    UploadDatasetImageFromGenResponseBody,
    UploadDatasetImageFromGenResponseBodyTypedDict,
    UploadDatasetImageFromGenResponseTypedDict,
)
from .uploadinitimage import (
    InitImageUploadOutput,
    InitImageUploadOutputTypedDict,
    UploadInitImageRequestBody,
    UploadInitImageRequestBodyTypedDict,
    UploadInitImageResponse,
    UploadInitImageResponseBody,
    UploadInitImageResponseBodyTypedDict,
    UploadInitImageResponseTypedDict,
)
from .uploadmodelasset import (
    ModelAssetUploadOutput,
    ModelAssetUploadOutputTypedDict,
    UploadModelAssetRequestBody,
    UploadModelAssetRequestBodyTypedDict,
    UploadModelAssetResponse,
    UploadModelAssetResponseBody,
    UploadModelAssetResponseBodyTypedDict,
    UploadModelAssetResponseTypedDict,
)

__all__ = [
    "CalculateProductionAPIServiceCost",
    "CalculateProductionAPIServiceCostTypedDict",
    "CanvasInitImageUploadOutput",
    "CanvasInitImageUploadOutputTypedDict",
    "CreateDatasetRequestBody",
    "CreateDatasetRequestBodyTypedDict",
    "CreateDatasetResponse",
    "CreateDatasetResponseBody",
    "CreateDatasetResponseBodyTypedDict",
    "CreateDatasetResponseTypedDict",
    "CreateElementRequestBody",
    "CreateElementRequestBodyTypedDict",
    "CreateElementResponse",
    "CreateElementResponseBody",
    "CreateElementResponseBodyTypedDict",
    "CreateElementResponseTypedDict",
    "CreateGenerationRequestBody",
    "CreateGenerationRequestBodyTypedDict",
    "CreateGenerationResponse",
    "CreateGenerationResponseBody",
    "CreateGenerationResponseBodyTypedDict",
    "CreateGenerationResponseTypedDict",
    "CreateLCMGenerationRequestBody",
    "CreateLCMGenerationRequestBodyTypedDict",
    "CreateLCMGenerationResponse",
    "CreateLCMGenerationResponseBody",
    "CreateLCMGenerationResponseBodyTypedDict",
    "CreateLCMGenerationResponseTypedDict",
    "CreateModelRequestBody",
    "CreateModelRequestBodyTypedDict",
    "CreateModelResponse",
    "CreateModelResponseBody",
    "CreateModelResponseBodyTypedDict",
    "CreateModelResponseTypedDict",
    "CreateModelSDTrainingOutput",
    "CreateModelSDTrainingOutputTypedDict",
    "CreateModelSdVersions",
    "CreateSVDMotionGenerationRequestBody",
    "CreateSVDMotionGenerationRequestBodyTypedDict",
    "CreateSVDMotionGenerationResponse",
    "CreateSVDMotionGenerationResponseBody",
    "CreateSVDMotionGenerationResponseBodyTypedDict",
    "CreateSVDMotionGenerationResponseTypedDict",
    "CreateTextureGenerationRequestBody",
    "CreateTextureGenerationRequestBodyTypedDict",
    "CreateTextureGenerationResponse",
    "CreateTextureGenerationResponseBody",
    "CreateTextureGenerationResponseBodyTypedDict",
    "CreateTextureGenerationResponseTypedDict",
    "CreateUniversalUpscalerJobRequestBody",
    "CreateUniversalUpscalerJobRequestBodyTypedDict",
    "CreateUniversalUpscalerJobResponse",
    "CreateUniversalUpscalerJobResponseBody",
    "CreateUniversalUpscalerJobResponseBodyTypedDict",
    "CreateUniversalUpscalerJobResponseTypedDict",
    "CreateVariationNoBGRequestBody",
    "CreateVariationNoBGRequestBodyTypedDict",
    "CreateVariationNoBGResponse",
    "CreateVariationNoBGResponseBody",
    "CreateVariationNoBGResponseBodyTypedDict",
    "CreateVariationNoBGResponseTypedDict",
    "CreateVariationUnzoomRequestBody",
    "CreateVariationUnzoomRequestBodyTypedDict",
    "CreateVariationUnzoomResponse",
    "CreateVariationUnzoomResponseBody",
    "CreateVariationUnzoomResponseBodyTypedDict",
    "CreateVariationUnzoomResponseTypedDict",
    "CreateVariationUpscaleRequestBody",
    "CreateVariationUpscaleRequestBodyTypedDict",
    "CreateVariationUpscaleResponse",
    "CreateVariationUpscaleResponseBody",
    "CreateVariationUpscaleResponseBodyTypedDict",
    "CreateVariationUpscaleResponseTypedDict",
    "CreateVariationUpscaleSDUpscaleJobOutput",
    "CreateVariationUpscaleSDUpscaleJobOutputTypedDict",
    "CustomModels",
    "CustomModelsTypedDict",
    "DatasetGenUploadOutput",
    "DatasetGenUploadOutputTypedDict",
    "DatasetImages",
    "DatasetImagesTypedDict",
    "DatasetUploadOutput",
    "DatasetUploadOutputTypedDict",
    "Datasets",
    "DatasetsTypedDict",
    "Delete3DModelByIDRequest",
    "Delete3DModelByIDRequestBody",
    "Delete3DModelByIDRequestBodyTypedDict",
    "Delete3DModelByIDRequestTypedDict",
    "Delete3DModelByIDResponse",
    "Delete3DModelByIDResponseBody",
    "Delete3DModelByIDResponseBodyTypedDict",
    "Delete3DModelByIDResponseTypedDict",
    "DeleteDatasetByIDDatasets",
    "DeleteDatasetByIDDatasetsTypedDict",
    "DeleteDatasetByIDRequest",
    "DeleteDatasetByIDRequestTypedDict",
    "DeleteDatasetByIDResponse",
    "DeleteDatasetByIDResponseBody",
    "DeleteDatasetByIDResponseBodyTypedDict",
    "DeleteDatasetByIDResponseTypedDict",
    "DeleteElementByIDRequest",
    "DeleteElementByIDRequestTypedDict",
    "DeleteElementByIDResponse",
    "DeleteElementByIDResponseBody",
    "DeleteElementByIDResponseBodyTypedDict",
    "DeleteElementByIDResponseTypedDict",
    "DeleteGenerationByIDRequest",
    "DeleteGenerationByIDRequestTypedDict",
    "DeleteGenerationByIDResponse",
    "DeleteGenerationByIDResponseBody",
    "DeleteGenerationByIDResponseBodyTypedDict",
    "DeleteGenerationByIDResponseTypedDict",
    "DeleteInitImageByIDRequest",
    "DeleteInitImageByIDRequestTypedDict",
    "DeleteInitImageByIDResponse",
    "DeleteInitImageByIDResponseBody",
    "DeleteInitImageByIDResponseBodyTypedDict",
    "DeleteInitImageByIDResponseTypedDict",
    "DeleteModelByIDRequest",
    "DeleteModelByIDRequestTypedDict",
    "DeleteModelByIDResponse",
    "DeleteModelByIDResponseBody",
    "DeleteModelByIDResponseBodyTypedDict",
    "DeleteModelByIDResponseTypedDict",
    "DeleteTextureGenerationByIDRequest",
    "DeleteTextureGenerationByIDRequestBody",
    "DeleteTextureGenerationByIDRequestBodyTypedDict",
    "DeleteTextureGenerationByIDRequestTypedDict",
    "DeleteTextureGenerationByIDResponse",
    "DeleteTextureGenerationByIDResponseBody",
    "DeleteTextureGenerationByIDResponseBodyTypedDict",
    "DeleteTextureGenerationByIDResponseTypedDict",
    "Elements",
    "ElementsTypedDict",
    "GeneratedImageVariationGeneric",
    "GeneratedImageVariationGenericTypedDict",
    "GeneratedImages",
    "GeneratedImagesTypedDict",
    "GenerationElements",
    "GenerationElementsTypedDict",
    "Generations",
    "GenerationsTypedDict",
    "Get3DModelByIDModelAssets",
    "Get3DModelByIDModelAssetsTypedDict",
    "Get3DModelByIDRequest",
    "Get3DModelByIDRequestBody",
    "Get3DModelByIDRequestBodyTypedDict",
    "Get3DModelByIDRequestTypedDict",
    "Get3DModelByIDResponse",
    "Get3DModelByIDResponseBody",
    "Get3DModelByIDResponseBodyTypedDict",
    "Get3DModelByIDResponseTypedDict",
    "Get3DModelsByUserIDModelAssets",
    "Get3DModelsByUserIDModelAssetsTypedDict",
    "Get3DModelsByUserIDRequest",
    "Get3DModelsByUserIDRequestBody",
    "Get3DModelsByUserIDRequestBodyTypedDict",
    "Get3DModelsByUserIDRequestTypedDict",
    "Get3DModelsByUserIDResponse",
    "Get3DModelsByUserIDResponseBody",
    "Get3DModelsByUserIDResponseBodyTypedDict",
    "Get3DModelsByUserIDResponseTypedDict",
    "GetCustomElementsByUserIDRequest",
    "GetCustomElementsByUserIDRequestTypedDict",
    "GetCustomElementsByUserIDResponse",
    "GetCustomElementsByUserIDResponseBody",
    "GetCustomElementsByUserIDResponseBodyTypedDict",
    "GetCustomElementsByUserIDResponseTypedDict",
    "GetCustomElementsByUserIDUserLoras",
    "GetCustomElementsByUserIDUserLorasTypedDict",
    "GetCustomModelsByUserIDCustomModels",
    "GetCustomModelsByUserIDCustomModelsTypedDict",
    "GetCustomModelsByUserIDRequest",
    "GetCustomModelsByUserIDRequestTypedDict",
    "GetCustomModelsByUserIDResponse",
    "GetCustomModelsByUserIDResponseBody",
    "GetCustomModelsByUserIDResponseBodyTypedDict",
    "GetCustomModelsByUserIDResponseTypedDict",
    "GetDatasetByIDDatasets",
    "GetDatasetByIDDatasetsTypedDict",
    "GetDatasetByIDRequest",
    "GetDatasetByIDRequestTypedDict",
    "GetDatasetByIDResponse",
    "GetDatasetByIDResponseBody",
    "GetDatasetByIDResponseBodyTypedDict",
    "GetDatasetByIDResponseTypedDict",
    "GetElementByIDRequest",
    "GetElementByIDRequestTypedDict",
    "GetElementByIDResponse",
    "GetElementByIDResponseBody",
    "GetElementByIDResponseBodyTypedDict",
    "GetElementByIDResponseTypedDict",
    "GetElementByIDUserLoras",
    "GetElementByIDUserLorasTypedDict",
    "GetGenerationByIDGeneratedImageVariationGeneric",
    "GetGenerationByIDGeneratedImageVariationGenericTypedDict",
    "GetGenerationByIDGenerations",
    "GetGenerationByIDGenerationsTypedDict",
    "GetGenerationByIDLoras",
    "GetGenerationByIDLorasTypedDict",
    "GetGenerationByIDRequest",
    "GetGenerationByIDRequestTypedDict",
    "GetGenerationByIDResponse",
    "GetGenerationByIDResponseBody",
    "GetGenerationByIDResponseBodyTypedDict",
    "GetGenerationByIDResponseTypedDict",
    "GetGenerationsByUserIDGeneratedImageVariationGeneric",
    "GetGenerationsByUserIDGeneratedImageVariationGenericTypedDict",
    "GetGenerationsByUserIDGeneratedImages",
    "GetGenerationsByUserIDGeneratedImagesTypedDict",
    "GetGenerationsByUserIDGenerationElements",
    "GetGenerationsByUserIDGenerationElementsTypedDict",
    "GetGenerationsByUserIDGenerations",
    "GetGenerationsByUserIDGenerationsTypedDict",
    "GetGenerationsByUserIDRequest",
    "GetGenerationsByUserIDRequestTypedDict",
    "GetGenerationsByUserIDResponse",
    "GetGenerationsByUserIDResponseBody",
    "GetGenerationsByUserIDResponseBodyTypedDict",
    "GetGenerationsByUserIDResponseTypedDict",
    "GetInitImageByIDInitImages",
    "GetInitImageByIDInitImagesTypedDict",
    "GetInitImageByIDRequest",
    "GetInitImageByIDRequestTypedDict",
    "GetInitImageByIDResponse",
    "GetInitImageByIDResponseBody",
    "GetInitImageByIDResponseBodyTypedDict",
    "GetInitImageByIDResponseTypedDict",
    "GetModelByIDCustomModels",
    "GetModelByIDCustomModelsTypedDict",
    "GetModelByIDRequest",
    "GetModelByIDRequestTypedDict",
    "GetModelByIDResponse",
    "GetModelByIDResponseBody",
    "GetModelByIDResponseBodyTypedDict",
    "GetModelByIDResponseTypedDict",
    "GetTextureGenerationByIDModelAssetTextureGenerations",
    "GetTextureGenerationByIDModelAssetTextureGenerationsTypedDict",
    "GetTextureGenerationByIDRequest",
    "GetTextureGenerationByIDRequestBody",
    "GetTextureGenerationByIDRequestBodyTypedDict",
    "GetTextureGenerationByIDRequestTypedDict",
    "GetTextureGenerationByIDResponse",
    "GetTextureGenerationByIDResponseBody",
    "GetTextureGenerationByIDResponseBodyTypedDict",
    "GetTextureGenerationByIDResponseTypedDict",
    "GetTextureGenerationsByModelIDModelAssetTextureGenerations",
    "GetTextureGenerationsByModelIDModelAssetTextureGenerationsTypedDict",
    "GetTextureGenerationsByModelIDModelAssetTextureImages",
    "GetTextureGenerationsByModelIDModelAssetTextureImagesTypedDict",
    "GetTextureGenerationsByModelIDRequest",
    "GetTextureGenerationsByModelIDRequestBody",
    "GetTextureGenerationsByModelIDRequestBodyTypedDict",
    "GetTextureGenerationsByModelIDRequestTypedDict",
    "GetTextureGenerationsByModelIDResponse",
    "GetTextureGenerationsByModelIDResponseBody",
    "GetTextureGenerationsByModelIDResponseBodyTypedDict",
    "GetTextureGenerationsByModelIDResponseTypedDict",
    "GetUserSelfResponse",
    "GetUserSelfResponseBody",
    "GetUserSelfResponseBodyTypedDict",
    "GetUserSelfResponseTypedDict",
    "GetVariationByIDRequest",
    "GetVariationByIDRequestTypedDict",
    "GetVariationByIDResponse",
    "GetVariationByIDResponseBody",
    "GetVariationByIDResponseBodyTypedDict",
    "GetVariationByIDResponseTypedDict",
    "InitImageUploadOutput",
    "InitImageUploadOutputTypedDict",
    "InitImages",
    "InitImagesTypedDict",
    "LcmGenerationOutput",
    "LcmGenerationOutputTypedDict",
    "ListElementsResponse",
    "ListElementsResponseBody",
    "ListElementsResponseBodyTypedDict",
    "ListElementsResponseTypedDict",
    "ListPlatformModelsCustomModels",
    "ListPlatformModelsCustomModelsTypedDict",
    "ListPlatformModelsGeneratedImages",
    "ListPlatformModelsGeneratedImagesTypedDict",
    "ListPlatformModelsResponse",
    "ListPlatformModelsResponseBody",
    "ListPlatformModelsResponseBodyTypedDict",
    "ListPlatformModelsResponseTypedDict",
    "Loras",
    "LorasTypedDict",
    "ModelAssetTextureGenerations",
    "ModelAssetTextureGenerationsTypedDict",
    "ModelAssetTextureImages",
    "ModelAssetTextureImagesTypedDict",
    "ModelAssetUploadOutput",
    "ModelAssetUploadOutputTypedDict",
    "ModelAssets",
    "ModelAssetsTypedDict",
    "MotionSvdGenerationOutput",
    "MotionSvdGenerationOutputTypedDict",
    "Object",
    "ObjectTypedDict",
    "PerformAlchemyUpscaleLCMLCMGenerationOutput",
    "PerformAlchemyUpscaleLCMLCMGenerationOutputTypedDict",
    "PerformAlchemyUpscaleLCMRequestBody",
    "PerformAlchemyUpscaleLCMRequestBodyTypedDict",
    "PerformAlchemyUpscaleLCMResponse",
    "PerformAlchemyUpscaleLCMResponseBody",
    "PerformAlchemyUpscaleLCMResponseBodyTypedDict",
    "PerformAlchemyUpscaleLCMResponseTypedDict",
    "PerformInpaintingLCMLCMGenerationOutput",
    "PerformInpaintingLCMLCMGenerationOutputTypedDict",
    "PerformInpaintingLCMRequestBody",
    "PerformInpaintingLCMRequestBodyTypedDict",
    "PerformInpaintingLCMResponse",
    "PerformInpaintingLCMResponseBody",
    "PerformInpaintingLCMResponseBodyTypedDict",
    "PerformInpaintingLCMResponseTypedDict",
    "PerformInstantRefineLcmGenerationOutput",
    "PerformInstantRefineLcmGenerationOutputTypedDict",
    "PerformInstantRefineRequestBody",
    "PerformInstantRefineRequestBodyTypedDict",
    "PerformInstantRefineResponse",
    "PerformInstantRefineResponseBody",
    "PerformInstantRefineResponseBodyTypedDict",
    "PerformInstantRefineResponseTypedDict",
    "PricingCalculatorObject",
    "PricingCalculatorObjectTypedDict",
    "PricingCalculatorPricingCalculatorObject",
    "PricingCalculatorPricingCalculatorObjectTypedDict",
    "PricingCalculatorPricingCalculatorRequestObject",
    "PricingCalculatorPricingCalculatorRequestObjectTypedDict",
    "PricingCalculatorPricingCalculatorRequestRequestBodyObject",
    "PricingCalculatorPricingCalculatorRequestRequestBodyObjectTypedDict",
    "PricingCalculatorPricingCalculatorRequestRequestBodyServiceParamsObject",
    "PricingCalculatorPricingCalculatorRequestRequestBodyServiceParamsObjectTypedDict",
    "PricingCalculatorPricingCalculatorRequestRequestBodyServiceParamsTEXTUREGENERATIONObject",
    "PricingCalculatorPricingCalculatorRequestRequestBodyServiceParamsTEXTUREGENERATIONObjectTypedDict",
    "PricingCalculatorPricingCalculatorRequestRequestBodyServiceParamsUNIVERSALUPSCALERObject",
    "PricingCalculatorPricingCalculatorRequestRequestBodyServiceParamsUNIVERSALUPSCALERObjectTypedDict",
    "PricingCalculatorPricingCalculatorRequestRequestBodyServiceParamsUNIVERSALUPSCALERULTRAObject",
    "PricingCalculatorPricingCalculatorRequestRequestBodyServiceParamsUNIVERSALUPSCALERULTRAObjectTypedDict",
    "PricingCalculatorRequestBody",
    "PricingCalculatorRequestBodyTypedDict",
    "PricingCalculatorResponse",
    "PricingCalculatorResponseBody",
    "PricingCalculatorResponseBodyTypedDict",
    "PricingCalculatorResponseTypedDict",
    "PromptGenerationOutput",
    "PromptGenerationOutputTypedDict",
    "PromptImproveRequestBody",
    "PromptImproveRequestBodyTypedDict",
    "PromptImproveResponse",
    "PromptImproveResponseBody",
    "PromptImproveResponseBodyTypedDict",
    "PromptImproveResponseTypedDict",
    "PromptRandomPromptGenerationOutput",
    "PromptRandomPromptGenerationOutputTypedDict",
    "PromptRandomResponse",
    "PromptRandomResponseBody",
    "PromptRandomResponseBodyTypedDict",
    "PromptRandomResponseTypedDict",
    "SDGenerationOutput",
    "SDGenerationOutputTypedDict",
    "SDTrainingOutput",
    "SDTrainingOutputTypedDict",
    "SDUnzoomOutput",
    "SDUnzoomOutputTypedDict",
    "SDUpscaleJobOutput",
    "SDUpscaleJobOutputTypedDict",
    "SdVersions",
    "TextureGenerationJobOutput",
    "TextureGenerationJobOutputTypedDict",
    "TransparencyType",
    "UniversalUpscalerOutput",
    "UniversalUpscalerOutputTypedDict",
    "UploadCanvasInitImageRequestBody",
    "UploadCanvasInitImageRequestBodyTypedDict",
    "UploadCanvasInitImageResponse",
    "UploadCanvasInitImageResponseBody",
    "UploadCanvasInitImageResponseBodyTypedDict",
    "UploadCanvasInitImageResponseTypedDict",
    "UploadDatasetImageFromGenRequest",
    "UploadDatasetImageFromGenRequestBody",
    "UploadDatasetImageFromGenRequestBodyTypedDict",
    "UploadDatasetImageFromGenRequestTypedDict",
    "UploadDatasetImageFromGenResponse",
    "UploadDatasetImageFromGenResponseBody",
    "UploadDatasetImageFromGenResponseBodyTypedDict",
    "UploadDatasetImageFromGenResponseTypedDict",
    "UploadDatasetImageRequest",
    "UploadDatasetImageRequestBody",
    "UploadDatasetImageRequestBodyTypedDict",
    "UploadDatasetImageRequestTypedDict",
    "UploadDatasetImageResponse",
    "UploadDatasetImageResponseBody",
    "UploadDatasetImageResponseBodyTypedDict",
    "UploadDatasetImageResponseTypedDict",
    "UploadInitImageRequestBody",
    "UploadInitImageRequestBodyTypedDict",
    "UploadInitImageResponse",
    "UploadInitImageResponseBody",
    "UploadInitImageResponseBodyTypedDict",
    "UploadInitImageResponseTypedDict",
    "UploadModelAssetRequestBody",
    "UploadModelAssetRequestBodyTypedDict",
    "UploadModelAssetResponse",
    "UploadModelAssetResponseBody",
    "UploadModelAssetResponseBodyTypedDict",
    "UploadModelAssetResponseTypedDict",
    "UserDetails",
    "UserDetailsTypedDict",
    "UserLoras",
    "UserLorasTypedDict",
    "Users",
    "UsersTypedDict",
]
